@@ -47,8 +47,6 @@ these are the ones:
 
 =item * L<Game::TextMapper::Smale>
 
-=item * L<Game::TextMapper::Solo>
-
 =item * L<Game::TextMapper::Traveller>
 
 =back
@@ -116,7 +114,6 @@ use Mojo::Base 'Mojolicious::Command';
 use Pod::Simple::Text;
 use Getopt::Long qw(GetOptionsFromArray);
 use Role::Tiny;
-binmode(STDOUT, ':utf8');
 
 has description => 'Print a random map to STDOUT';
 
